-- automatically get the addon version number
WN_version = GetAddOnMetadata("WhisperNotify", "Version");

-- Set up the default configuration. If there is a saved config, this will be overwritten when it is loaded by the system.
WhisperNotify_Config = {
	State = true,
	Sound = true,
	SoundTime = 15,
--	SoundFile = 'LEVELUP',
	SoundFile = 'psst.ogg',
	Time = 5,
	Fade = 2,
	Style = 'DEFAULT',
	Combat = true,
	FontSize = 30,
	FontOutline = "NORMAL",
	FontColor = {1,0.5,1,1},
	Font = 'Fonts\\skurri.ttf'
	};		

local wLast = 1262304000;

-- handy little function
function round(num, idp)
  local mult = 10^(idp or 0)
  return math.floor(num * mult + 0.5) / mult
end


-- Prints out debugging info (undocumented feature)
function WhisperNotify_Debug()
	print ('State:',WhisperNotify_Config.State);
	print ('Sound: ',WhisperNotify_Config.Sound) ;
	print ('SoundTime: ',WhisperNotify_Config.SoundTime) ;
	print ('SoundFile: ',WhisperNotify_Config.SoundFile) ;
--	print ('Time:',WhisperNotify_Config.Time);
--	print ('Fade:',WhisperNotify_Config.Fade);
--	print ('Style:',WhisperNotify_Config.Style);
--	print ('Combat:',WhisperNotify_Config.Combat);
--	print ('Font:',WhisperNotify_Config.Font);
--	print ('FontSize:',WhisperNotify_Config.FontSize);
	print ('---------------');

--	local time = WhisperNotifyFrame:GetTimeVisible(); 
--	local fade = WhisperNotifyFrame:GetFadeDuration();
--	local width, height = WhisperNotifyFrame:GetSize(); -- Returns the width and height of the region
--      local filename, fontHeight, flags = WhisperNotifyFrame:GetFont(); -- Returns the font instance's basic font properties
--      local fontobject = WhisperNotifyFrame:GetFontObject(); -- Returns the `Font` object from which the font instance's properties are inherited
--      local textR, textG, textB, textAlpha = WhisperNotifyFrame:GetTextColor(); -- Returns the font instance's default text color
--	local clampenabled = WhisperNotifyFrame:IsClampedToScreen(); -- Returns whether the frame's boundaries are limited to those of the screen
--	local movable = WhisperNotifyFrame:IsMovable(); -- Returns whether the frame can be moved by the user
--	local resizable = WhisperNotifyFrame:IsResizable(); -- Returns whether the frame can be resized by the user
--	local shown = WhisperNotifyFrame:IsShown(); -- Returns whether the region is shown        
--	local userplaced = WhisperNotifyFrame:IsUserPlaced(); -- Returns whether the frame is flagged for automatic saving and restoration of position and dimensions
--	local visible = WhisperNotifyFrame:IsVisible(); -- Returns whether the region is visible
--	local addonload_registered = WhisperNotifyFrame:IsEventRegistered("ADDON_LOADED"); -- Returns whether the frame is registered for a given [[docs/events|event]]
--	local playerwhisper_registered = WhisperNotifyFrame:IsEventRegistered("CHAT_MSG_WHISPER"); -- Returns whether the frame is registered for a given [[docs/events|event]]
--	local npcwhisperregistered = WhisperNotifyFrame:IsEventRegistered("CHAT_MSG_MONSTER_WHISPER"); -- Returns whether the frame is registered for a given [[docs/events|event]]
	
--	print('Time: ', time); 
--	print('Fade: ', fade);
--	print('width: ', round(width,0));
--     	print('height: ', round(height,0));
--	print('font filename: ', filename);
--	print('font Height: ', fontHeight);
--	print('font flags: ', flags);
--	print('font object: ', fontobject) ;
--	print('textR: ', textR);
--	print('textG: ', textG);
--	print('textB: ', textB);
--	print('textAlpha: ', textAlpha) ;
	
--	print ('NumPoints:',WhisperNotifyFrame:GetNumPoints());
	
--	local point2, relativeTo2, relativePoint2, xOfs2, yOfs2 = WhisperNotifyFrame:GetPoint();
--	print (point2);
--	print (relativeTo2:GetName());
--	print (relativePoint2);
--	print (xOfs2);
--	print (yOfs2);

end --WhisperNotify_Debug


-- Resets all options to defaults
function WhisperNotify_Reset()
	WhisperNotify_Config.State = true;
	WhisperNotify_Config.Sound = true;
	WhisperNotify_Config.SoundTime = 15;
--	WhisperNotify_Config.SoundFile = 'LEVELUP';
	WhisperNotify_Config.SoundFile = 'psst.ogg';
	WhisperNotify_Config.Time = 5;
	WhisperNotify_Config.Fade = 2;
	WhisperNotify_Config.Style = 'DEFAULT';
	WhisperNotify_Config.Combat = true;
	WhisperNotify_Config.FontSize = 30;
	WhisperNotify_Config.FontOutline = 'NORMAL';
	WhisperNotify_Config.FontColor = {1,0.5,1,1};
	WhisperNotify_Config.Font = 'Fonts\skurri.ttf';
	WhisperNotifyFrame:SetFont(WhisperNotify_Config.Font, WhisperNotify_Config.FontSize); --new
	WhisperNotifyFrame:SetTimeVisible(WhisperNotify_Config.Time);
	WhisperNotifyFrame:SetFadeDuration(WhisperNotify_Config.Fade);
	WhisperNotifyFrame:SetTextColor(1, 0.5, 1, 1);
	WhisperNotifyFrame:ClearAllPoints();
	WhisperNotifyFrame:SetPoint("CENTER", "UIParent", 0, 0 );
	WhisperNotifyFrame:SetSize(600, 200);
	WhisperNotifyFrame:SetUserPlaced(true);
	print('All WhisperNotify options now reset to default values.');	
end --WhisperNotify_Reset


-- Changes the offset of the frame (Default is center of screen)
function WhisperNotify_Move(cords)
	local cord1, cord2 = cords:match("^(%S*)%s*(.-)$");
	local horz = tonumber(cord1);
	local vert = tonumber(cord2);
	
	if horz ~= nil and vert ~= nil then
		WhisperNotifyFrame:ClearAllPoints();
		WhisperNotifyFrame:SetPoint("CENTER", "UIParent", horz, vert );
		WhisperNotifyFrame:SetUserPlaced(true);
		print ('WhisperNotify frame moved to offset ',horz,', ',vert);
	else
		print ('Proper format for move command is "/wn move X Y" where X and Y are numbers');
		print ('Negative values will move frame left, positive values will move frame right');
		print ('Negative values will move frame down, positive values will move frame up');
		print ('Note: Frame cannot be moved offscreen');
	end

end --WhisperNotify_Move


-- Changes the size of the frame (Default is 600x200)
function WhisperNotify_Resize(sizes)
	local size1, size2 = sizes:match("^(%S*)%s*(.-)$");
	local width = tonumber(size1);
	local height = tonumber(size2);
	
	if width ~= nil and height ~= nil then
		WhisperNotifyFrame:SetSize(width, height);
		WhisperNotifyFrame:SetUserPlaced(true);
		print ('WhisperNotify frame resized to ',width,' x ',height);
	else
		print ('Proper format for resize command is "/wn resize W H" where W and H are numbers');
		print ('Default frame size is 600 wide x 200 high');
	end

end --WhisperNotify_Resize


-- Prints out status for the user
function WhisperNotify_ShowStatus()
	print('WhisperNotify current status:');
	if WhisperNotify_Config.State then 
		print('WhisperNotify turned on for this character.');
	else
		print('WhisperNotify turned off for this character.');
	end  
	if WhisperNotify_Config.Sound then 
		print('WhisperNotify alert sound turned on for this character.');
	else
		print('WhisperNotify alert sound turned off for this character.');
	end  
	if WhisperNotify_Config.Style == 'DEFAULT' then 
		print('WhisperNotify Style: Default');
	else
		print('WhisperNotify Style: Compact');
	end  
--	print('WhisperNotify Style: ',WhisperNotify_Config.Style);
	if WhisperNotify_Config.Combat then 
		print('WhisperNotify Show in combat: Yes');
	else
		print('WhisperNotify Show in combat: No');
	end  
	print('WhisperNotify timer: ', WhisperNotify_Config.Time, ' seconds.');
	print('WhisperNotify fade timer: ', WhisperNotify_Config.Fade, ' seconds.');

end --WhisperNotify_ShowStatus


-- Prints out the slash commands for the user
function WhisperNotify_HelpCommands()
	print('You wanted something?' );
	print('/wn ver - get version info' );
	print('/wn reset - resets all options to defaults.' );
	print('/wn on - turn WhisperNotify on for the current character.' ); 
	print('/wn off - turn WhisperNotify off for the current character.' ); 
	print('/wn sound - toggles alert sound on/off for the current character' ); 
	print('/wn status - display the WhisperNotify Status for the current character' );
	print('/wn style - toggles bewteen the default and compact display styles' );
	print('/wn combat - toggles display in combat on and off' );
	print('/wn test - sends a test whisper to the on screen diplay' ); 
	print('/wn time S - sets time whispers stay on screen before starting to fade to S seconds (default is 5)' ); 
	print('/wn fade S - sets time whispers take to fade out to S seconds (default is 2)' ); 
	print('/wn move X Y - sets the offset of the frame from the center of the screen' ); 
	print('/wn resize W H - sets the size the frame. Default is 600x200' ); 
  
end --WhisperNotify_HelpCommands


-- Set up the Slash Commands and Handler
SLASH_WHISPERNOTIFY1, SLASH_WHISPERNOTIFY2 = '/wn', '/whispernotify'; 
local function handler(msg, editbox)
-- local cmd = msg:lower()
 local cmd, rest = msg:match("^(%S*)%s*(.-)$");

 if cmd == 'ver' then
	print('WhisperNotify v'..WN_version);

 elseif cmd == 'on' then
	WhisperNotify_Config.State = true;
	print('Whisper notification now on for this character.');

 elseif cmd == 'off' then
	WhisperNotify_Config.State = false;
	print('Whisper notification now off for this character.');

 elseif cmd == 'sound' then
	if WhisperNotify_Config.Sound then 
		WhisperNotify_Config.Sound = false; 
		print('WhisperNotify alert sound now turned off for this character.');
	else 
		WhisperNotify_Config.Sound = true; 
		print('WhisperNotify alert sound now turned on for this character.');
	end

 elseif cmd == 'combat' then
	if WhisperNotify_Config.Combat then 
		WhisperNotify_Config.Combat = false; 
		print('WhisperNotify display in combat now turned off for this character.');
	else 
		WhisperNotify_Config.Combat = true; 
		print('WhisperNotify display in combat now turned on for this character.');
	end
  
 elseif cmd == 'style' then
	if WhisperNotify_Config.Style == 'DEFAULT' then 
		WhisperNotify_Config.Style = 'COMPACT' 
		print('WhisperNotify now set to Compact style.');
	else 
	        WhisperNotify_Config.Style = 'DEFAULT';
	        print('WhisperNotify now set to Default style.');
	end
  
 elseif cmd == 'test' then
 	SendChatMessage('How many whispers would a whisp whisper if a whisp could whisper?',"WHISPER",nil,UnitName("player"));

 elseif cmd == 'status' then
	WhisperNotify_ShowStatus(); 
 
 elseif cmd == 'debug' then
	WhisperNotify_Debug();
 
 elseif cmd == 'time'  and rest ~= "" then
    tempNum = tonumber(rest);
    if tempNum ~= nil then
    	WhisperNotify_Config.Time = tempNum;
	WhisperNotifyFrame:SetTimeVisible(WhisperNotify_Config.Time)
        print('WhisperNotify display time set to',WhisperNotify_Config.Time, 'seconds.');
    end

 elseif cmd == 'fade'  and rest ~= "" then
    tempNum = tonumber(rest);
    if tempNum ~= nil then
    	WhisperNotify_Config.Fade = tempNum;
	WhisperNotifyFrame:SetFadeDuration(WhisperNotify_Config.Fade)
        print('WhisperNotify fade time set to',WhisperNotify_Config.Fade, 'seconds.');
    end
 
 elseif cmd == 'reset' then
 	WhisperNotify_Reset();
 
 elseif cmd == 'move'  and rest ~= "" then
 	WhisperNotify_Move(rest);
 
 elseif cmd == 'resize'  and rest ~= "" then
 	WhisperNotify_Resize(rest);
 
 else
	WhisperNotify_HelpCommands();

 end -- if
end -- handler
SlashCmdList["WHISPERNOTIFY"] = handler; 


function WhisperNotify_Defaults()
	if WhisperNotify_Config.State == nil then 
		WhisperNotify_Config.State = true;
	end
	if WhisperNotify_Config.Sound == nil then 
		WhisperNotify_Config.Sound = true;
	end
	if WhisperNotify_Config.SoundTime == nil then 
		WhisperNotify_Config.SoundTime = 15;
	end
	if WhisperNotify_Config.SoundFile == nil then 
--		WhisperNotify_Config.SoundFile = 'LEVELUP';
		WhisperNotify_Config.SoundFile = 'psst.ogg';
	end	
	if WhisperNotify_Config.Time == nil then 
		WhisperNotify_Config.Time = 5;
	end
	if WhisperNotify_Config.Fade == nil then 
		WhisperNotify_Config.Fade = 2;
	end
	if WhisperNotify_Config.Style == nil then 
		WhisperNotify_Config.Style = 'DEFAULT';
	end
	if WhisperNotify_Config.Combat == nil then 
		WhisperNotify_Config.Combat = true;
	end
	if WhisperNotify_Config.FontSize == nil then 
		WhisperNotify_Config.FontSize = 30;
	end
	if WhisperNotify_Config.FontOutline == nil then 
		WhisperNotify_Config.FontOutline = "NORMAL";
	end
	if WhisperNotify_Config.FontColor == nil then 
		WhisperNotify_Config.FontColor = {1,0.5,1,1};
	end
	if WhisperNotify_Config.Font == nil then 
		WhisperNotify_Config.Font = 'Fonts\skurri.ttf'
	end
end --WhisperNotify_defaults


function WhisperNotify_OnEvent(self, event, ...)
  local arg1, arg2 = ...;
  
  if (event == "ADDON_LOADED") and (arg1 == "WhisperNotify") then
	WhisperNotify_Defaults();
	WhisperNotifyFrame:SetTimeVisible(WhisperNotify_Config.Time);
	WhisperNotifyFrame:SetFadeDuration(WhisperNotify_Config.Fade);
	WhisperNotifyFrame:SetFont(WhisperNotify_Config.Font, WhisperNotify_Config.FontSize); --new
	WhisperNotifyFrame:SetMovable(true);
	WhisperNotifyFrame:SetResizable(true);
	WhisperNotifyFrame:SetClampedToScreen(true);
	WhisperNotifyConfig:Init();
	WhisperNotifyConfig2:Init();
	WhisperNotifyConfig3:Init();
	WhisperNotifyFrame:UnregisterEvent("ADDON_LOADED"); -- No need to waste CPU with loading events for other addons.
  	print('WhisperNotify v'..WN_version..' fully loaded.'); 
  end --if
  
  
  if(event == "CHAT_MSG_WHISPER" or event == "CHAT_MSG_MONSTER_WHISPER" or event == "CHAT_MSG_BN_WHISPER") then
--  	print('Debug - Combat1:', WhisperNotify_Config.Combat); -- Debugging code
--  	print('Debug - Combat2:', UnitAffectingCombat("player")); -- Debugging code
  	if WhisperNotify_Config.Combat == false and UnitAffectingCombat("player") == 1 then return end;
  	
  	if WhisperNotify_Config.State == true then
		if WhisperNotify_Config.Sound == true then
			--print ("wLast: ", wLast); -- Debugging code
			local wNow = time();
			--print ("wNow: ", wNow); -- Debugging code
			local wDiff = wNow - wLast;
			--print ("wDiff: ", wDiff); -- Debugging code
	  		if(wDiff > WhisperNotify_Config.SoundTime) then
	  			--PlaySound(WhisperNotify_Config.SoundFile);
	  			PlaySoundFile("Interface\\AddOns\\WhisperNotify\\SoundFX\\"..WhisperNotify_Config.SoundFile)
	  			--wLast = wNow; --Having this here will cause the timer to reset only when the sound is played, even if there is a steady stream of messages.
	  		end -- if wDiff
	  		wLast = wNow; --Having this here will cause the timer to reset whenever a message comes in, regardles of if the sound played.
  		end  --if sound
  		local r,g,b,a = unpack(WhisperNotify_Config.FontColor);
		if WhisperNotify_Config.Style == 'DEFAULT' then
			WhisperNotifyFrame:AddMessage(arg2, r, g, b, a);
   	  		WhisperNotifyFrame:AddMessage(arg1, r, g, b, a);
		else
			WhisperNotifyFrame:AddMessage(arg2..': '..arg1, r, g, b, a);
		end --if style
  	end --if state
  end --if event
  
end


function WhisperNotify_OnLoad() 
	-- Register the Events we want to trigger on
	WhisperNotifyFrame:RegisterEvent("ADDON_LOADED");
	WhisperNotifyFrame:RegisterEvent("CHAT_MSG_WHISPER");
	WhisperNotifyFrame:RegisterEvent("CHAT_MSG_MONSTER_WHISPER");
	WhisperNotifyFrame:RegisterEvent("CHAT_MSG_BN_WHISPER");
end 
