local config = CreateFrame("Frame");
local config2 = CreateFrame("Frame");
local config3 = CreateFrame("Frame");


WhisperNotifyConfig = config;
WhisperNotifyConfig2 = config2;
WhisperNotifyConfig3 = config3;

local fonttable = {	        
			       
[1]  = {"FrizQT"   , "Fonts\\FRIZQT__.TTF"  },
[2]  = {"Arialn"   , "Fonts\\ARIALN.TTF"     },
[3]  = {"Skurri"   , "Fonts\\skurri.ttf"     },
[4]  = {"Morpheus" , "Fonts\\MORPHEUS.ttf"   },
[5]  = {"Friends"  , "Fonts\\FRIENDS.TTF"    },
};


local soundtable = {
[1]  = {"Alarm Clock 1"		,"alarm_clock_1.ogg"},
[2]  = {"Alarm Clock 2"		,"alarm_clock_2.ogg"},
[3]  = {"Bottle Pop 1"		,"bottle_pop_2.ogg"},
[4]  = {"Bottle Pop 2"		,"bottle_pop_3.ogg"},
[5]  = {"Can Open"		,"can-open.ogg"},
[6]  = {"Can Table"		,"can-to-table.ogg"},
[7]  = {"Car Door"		,"car_door_close.ogg"},
[8]  = {"Lighter"		,"cigarette_lighter.ogg"},
[9]  = {"Throat"		,"clearing-throat.ogg"},
[10] = {"Clong"			,"clong_2.ogg"},
[11] = {"Coins"			,"coin_1.ogg"},
[12] = {"Door Close"		,"door-close.ogg"},
[13] = {"Door Cpen"		,"door-open.ogg"},
[14] = {"Electric Stapler"	,"electronic_stapler.ogg"},
[15] = {"Rude"			,"rude.ogg"},
[16] = {"Glass"			,"glass_breaking.ogg"},
[17] = {"Knock"			,"knocking.ogg"},
[18] = {"Switch 1"		,"light-switch-1.ogg"},
[19] = {"Switch 2"		,"light-switch-2.ogg"},
[20] = {"Magic Wand"		,"magic-wand.ogg"},
[21] = {"Matches"		,"matches.ogg"},
[22] = {"Metal Button"		,"metal_button.ogg"},
[23] = {"Microwave"		,"microwave-oven.ogg"},
[24] = {"Hang up"		,"hang-up.ogg"},
[25] = {"Psst"			,"psst.ogg"},
[26] = {"sound12"		,"sound12.ogg"},
[27] = {"sound31"		,"sound31.ogg"},
[28] = {"sound4"		,"sound4.ogg"},
[29] = {"sound46"		,"sound46.ogg"},
[30] = {"Spring"		,"spring.ogg"},
[31] = {"Two-Pop"		,"two-pop.ogg"},
[32] = {"Zipper"		,"zipper.ogg"},
[33] = {"Custom 1"		,"custom.mp3"},
};


function config:SetDefaultConfig()
	WhisperNotify_Config = {};
		WhisperNotify_Config.State = true;
		WhisperNotify_Config.Sound = true;
		WhisperNotify_Config.SoundTime = 15;
		WhisperNotify_Config.Time = 5;
		WhisperNotify_Config.Fade = 2;
		WhisperNotify_Config.Style = 'DEFAULT';
		WhisperNotify_Config.Combat = true;
		WhisperNotify_Config.FontSize = 30;
		WhisperNotify_Config.FontOutline = 'NORMAL';
		WhisperNotify_Config.FontColor = {1,0.5,1,1};
		WhisperNotify_Config.Font = 'Fonts\\skurri.ttf';
end


function round(num, idp)
  local mult = 10^(idp or 0)
  return math.floor(num * mult + 0.5) / mult
end


local tempSizeH = round(WhisperNotifyFrame:GetWidth(),0);
local tempSizeV = round(WhisperNotifyFrame:GetHeight(),0);
local point, relativeTo, relativePoint, xOfs, yOfs = WhisperNotifyFrame:GetPoint(1)
local tempOffsetH = round(xOfs,0);
local tempOffsetV = round(yOfs,0);



function config:ChangeFont()
	WhisperNotify_Config.Font = self.value;								
	UIDropDownMenu_SetSelectedValue(config.ConfigFontStyle,self.value,self.text);
	WhisperNotifyFrame:SetFont(self.value, WhisperNotify_Config.FontSize); --new
	config.WhisperNotifyPreview:SetFont(self.value, WhisperNotify_Config.FontSize); --new
end


function config:ChangeFontSize(self,value)
	if(value == true) then
		local newval = config.fontsize:GetValue();
		config.currentfontsize:SetText(newval);
		WhisperNotify_Config.FontSize = newval;
		config.WhisperNotifyPreview:SetTextHeight(newval);
		WhisperNotifyFrame:SetFont(WhisperNotify_Config.Font, WhisperNotify_Config.FontSize); --new
	end
end


function config:ChangeTime(self,value)
	if(value == true) then
		local newval =config.time:GetValue();
		config.currenttime:SetText(newval);
		WhisperNotify_Config.Time=newval;
	end
end


function config:ChangeFade(self,value)
	if(value == true) then
		local newval =config.fade:GetValue();
		config.currentfade:SetText(newval);
		WhisperNotify_Config.Fade=newval;
	end
end


local function changedCallback(restore)
 	local newR, newG, newB, newA;
 	if restore then
 		newR, newG, newB, newA = unpack(restore);
 	else
 		newA, newR, newG, newB = OpacitySliderFrame:GetValue(), ColorPickerFrame:GetColorRGB();
 	end
 
 	r, g, b, a = newR, newG, newB, newA;
 	_G["WhisperNotify_FontColorButtonColorSwatch"]:SetVertexColor(r,g,b,a);
 	config.WhisperNotifyPreview:SetTextColor(r,g,b,a);
 	WhisperNotify_Config.FontColor = {r, g, b, a};
end


function config:ConfigFontColor_OnClick()
	
	local r,g,b,a = unpack(WhisperNotify_Config.FontColor);
	ColorPickerFrame:SetColorRGB(r,g,b);
	ColorPickerFrame.hasOpacity, ColorPickerFrame.opacity = (a ~= nil), a;
	ColorPickerFrame.previousValues = {r,g,b,a};
	ColorPickerFrame.func, ColorPickerFrame.opacityFunc, ColorPickerFrame.cancelFunc = changedCallback, changedCallback, changedCallback;
	ColorPickerFrame:Hide(); 
	ColorPickerFrame:Show();
end


function config:ChangeStyle()
	WhisperNotify_Config.Style = self.value;								
	UIDropDownMenu_SetSelectedValue(config.ConfigStyle,self.value,self.text);
end


function config:PerformReset()
	--Reset the Stored Config Variables
	WhisperNotify_Reset();
	--Reset the temp variables used for the positioning
	tempSizeH = 800;
	tempSizeV = 200;
	tempOffsetH = 0;
	tempOffsetV = 0;
	--Update the values in the config screen. 
	if WhisperNotify_Config.State == true then config.ConfigEnable:SetChecked(true) else config.ConfigEnable:SetChecked(false) end;
	if WhisperNotify_Config.Sound == true then config.ConfigSound:SetChecked(true) else config.ConfigSound:SetChecked(false) end;
	if WhisperNotify_Config.Combat == true then config.ConfigCombat:SetChecked(true) else config.ConfigCombat:SetChecked(false) end;		
	UIDropDownMenu_SetSelectedValue(config.ConfigStyle,WhisperNotify_Config.Style );
	config.time:SetValue(WhisperNotify_Config.Time);
	config.currenttime:SetText( WhisperNotify_Config.Time );
	config.fade:SetValue(WhisperNotify_Config.Fade);
	config.currentfade:SetText( WhisperNotify_Config.Fade );
	config.fontsize:SetValue(WhisperNotify_Config.FontSize);
	config.currentfontsize:SetText( WhisperNotify_Config.FontSize );
	config.WhisperNotifyPreview:SetFont(WhisperNotify_Config.Font, WhisperNotify_Config.FontSize); --new
	_G["WhisperNotify_FontColorButtonColorSwatch"]:SetVertexColor(unpack(WhisperNotify_Config.FontColor));
	config.WhisperNotifyPreview:SetTextColor(unpack(WhisperNotify_Config.FontColor));
	config2.sizeH:SetValue(tempSizeH);
	config2.currentsizeH:SetText( tempSizeH );
	config2.sizeV:SetValue(tempSizeV);
	config2.currentsizeV:SetText( tempSizeV );
	config2.offsetH:SetValue(tempOffsetH);
	config2.currentoffsetH:SetText( tempOffsetH );
	config2.offsetV:SetValue(tempOffsetV);
	config2.currentoffsetV:SetText( tempOffsetV );
	--Make sure the reset values are saved to the SaveVariables folder.
	WhisperNotifyFrame:SetUserPlaced(true);
end


function config:Init()
	if not (WhisperNotify_Config) then
		config:SetDefaultConfig();
	end

	config.name = "Whisper Notify";
	config:SetBackdrop({bgFile = "Interface/Tooltips/UI-Tooltip-Background", insets = { left = 2, right = 2, top = 2, bottom = 2 },})
	config:SetBackdropColor(0.05, 0.05, 0.05, .7)



-- *********************************************************************************************

  	local ConfigEnable = CreateFrame("CheckButton","WhisperNotify_Enable",config,"InterfaceOptionsCheckButtonTemplate");
  	config.ConfigEnable = ConfigEnable;
	ConfigEnable:SetPoint( "TOPLEFT", 16, -16 );
  	_G[ConfigEnable:GetName().."Text"]:SetText("|c00dfb802Enable Whispers");
--	ConfigEnable:SetScript("OnClick", config.ChangeEnable(self)); -- Can NOT get this to work with a remote function. Don't know why and at this point, don't care. 
	ConfigEnable:SetScript("OnClick", function(self)
		if self:GetChecked() == 1 then 
			WhisperNotify_Config.State = true;
		else
			WhisperNotify_Config.State = false;
		end -- if GetChecked
	end) -- function	
	if WhisperNotify_Config.State == true then ConfigEnable:SetChecked(true) else ConfigEnable:SetChecked(false) end;
  
-- *********************************************************************************************

  	local ConfigSound = CreateFrame("CheckButton","WhisperNotify_Sound",config,"InterfaceOptionsCheckButtonTemplate");
  	config.ConfigSound = ConfigSound;
  	ConfigSound:SetPoint("BOTTOMLEFT", ConfigEnable,0, -35)
  	_G[ConfigSound:GetName().."Text"]:SetText("|c00dfb802Enable Sound");
--	ConfigSound:SetScript("OnClick", config.ChangeSound(self)); -- Can NOT get this to work with a remote function. Don't know why and at this point, don't care. 
	ConfigSound:SetScript("OnClick", function(self)
		if self:GetChecked() == 1 then 
			WhisperNotify_Config.Sound = true
		else
			WhisperNotify_Config.Sound = false
		end -- if GetChecked
	end) -- function	
	if WhisperNotify_Config.Sound == true then ConfigSound:SetChecked(true) else ConfigSound:SetChecked(false) end;

-- *********************************************************************************************

  	local ConfigCombat = CreateFrame("CheckButton","WhisperNotify_Combat",config,"InterfaceOptionsCheckButtonTemplate");
  	config.ConfigCombat = ConfigCombat;
  	ConfigCombat:SetPoint("BOTTOMLEFT", ConfigSound,180, 0)
  	_G[ConfigCombat:GetName().."Text"]:SetText("|c00dfb802Enable in Combat");
--	ConfigCombat:SetScript("OnClick", config.ChangeCombat(self)); -- Can NOT get this to work with a remote function. Don't know why and at this point, don't care. 
	ConfigCombat:SetScript("OnClick", function(self)
		if self:GetChecked() == 1 then 
			WhisperNotify_Config.Combat = true
		else
			WhisperNotify_Config.Combat = false
		end -- if GetChecked
	end) -- function	
	if WhisperNotify_Config.Combat == true then ConfigCombat:SetChecked(true) else ConfigCombat:SetChecked(false) end;

-- *********************************************************************************************

	local ConfigReset = CreateFrame("BUTTON", nil, config, "UIPanelButtonTemplate");
	ConfigReset:SetWidth(100);
	ConfigReset:SetHeight(25);
	ConfigReset:SetText("Reset");
	ConfigReset:SetPoint("BOTTOMLEFT", ConfigEnable, 180, 0);
	ConfigReset:SetScript("OnClick", config.PerformReset);

-- *********************************************************************************************

	local ConfigStyleLabel = config:CreateFontString( nil, "ARTWORK", "GameFontHighlight" );
	config.ConfigStyleLabel = ConfigStyleLabel;
	ConfigStyleLabel:SetPoint( "BOTTOMLEFT" , ConfigSound,0,-40);
	ConfigStyleLabel:SetText( "|c00dfb802Whisper Style" );
	ConfigStyleLabel:Show();
	
	local ConfigStyle = CreateFrame("Frame", "WhisperNotify_StylePick", config, "UIDropDownMenuTemplate");
	config.ConfigStyle = ConfigStyle;
	ConfigStyle:SetPoint("RIGHT", ConfigStyleLabel,30, 0);
	ConfigStyle.initialize = function () 
		
		info = UIDropDownMenu_CreateInfo()
		info.text = "Default";
		info.func = config.ChangeStyle;
		info.value = "DEFAULT";
		if(WhisperNotify_Config.Style == info.value) then
			info.checked = true;
		else
			info.checked = false;
		end
		UIDropDownMenu_AddButton(info)
		info = UIDropDownMenu_CreateInfo();
		info.text = "Compact";
		info.func = config.ChangeStyle;
		info.value = "COMPACT";
		if(WhisperNotify_Config.Style == info.value) then
			info.checked = true;
			
		else
			info.checked = false;
		end
		UIDropDownMenu_AddButton(info)
	
	end;
	UIDropDownMenu_Initialize(ConfigStyle, ConfigStyle.initialize)
	UIDropDownMenu_SetSelectedValue(ConfigStyle,WhisperNotify_Config.Style );

-- *********************************************************************************************	
	
	local time = CreateFrame( "Slider", "WhisperNotify_TimeSlider", config, "OptionsSliderTemplate" );
	config.time = time;
	time.id = "time";
	time:SetPoint( "BOTTOMLEFT", ConfigStyleLabel, 0, -50 );
	time:SetWidth(150);
	time:SetHeight(20);
	time:SetOrientation('HORIZONTAL');
	time:SetScript("OnValueChanged",config.ChangeTime);
	time:SetMinMaxValues(1, 30) ;
	time:SetValueStep(1);
	time:SetValue(WhisperNotify_Config.Time);
	_G[ time:GetName().."Low" ]:SetText( '1' );
	_G[ time:GetName().."High" ]:SetText( '30' );
	_G[ time:GetName().."Text" ]:SetText( '|c00dfb802On Screen Time');


	local currenttime = config:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" );
	config.currenttime = currenttime;
	currenttime:SetPoint( "CENTER",  time, "BOTTOM", 0, -5);
	currenttime:SetText( WhisperNotify_Config.Time );

-- *********************************************************************************************

	local fade = CreateFrame( "Slider", "WhisperNotify_FadeSlider", config, "OptionsSliderTemplate" );
	config.fade = fade;
	fade.id = "fade";
	fade:SetPoint( "BOTTOMLEFT", time, 180, 0 );
	fade:SetWidth(150);
	fade:SetHeight(20);
	fade:SetOrientation('HORIZONTAL');
	fade:SetScript("OnValueChanged",config.ChangeFade);
	fade:SetMinMaxValues(1, 5) ;
	fade:SetValueStep(1);
	fade:SetValue(WhisperNotify_Config.Fade);
	_G[ fade:GetName().."Low" ]:SetText( '1' );
	_G[ fade:GetName().."High" ]:SetText( '5' );
	_G[ fade:GetName().."Text" ]:SetText( '|c00dfb802Fade Time');
	
	
	local currentfade = config:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" );
	config.currentfade = currentfade;
	currentfade:SetPoint( "CENTER",  fade, "BOTTOM", 0, -5);
	currentfade:SetText( WhisperNotify_Config.Fade );


-- *********************************************************************************************

	local ConfigFontStyleLabel = config:CreateFontString( nil, "ARTWORK", "GameFontHighlight" );
	config.ConfigFontStyleLabel = ConfigFontStyleLabel;
	ConfigFontStyleLabel:SetPoint( "BOTTOMLEFT" , time,0,-40);
	ConfigFontStyleLabel:SetText( "|c00dfb802Font Style" );
	ConfigFontStyleLabel:Show();
	
	local ConfigFontStyle = CreateFrame("Frame", "WhisperNotify_FontPick", config, "UIDropDownMenuTemplate");
	config.ConfigFontStyle = ConfigFontStyle;
	ConfigFontStyle:SetPoint("RIGHT", ConfigFontStyleLabel,30, 0);
	ConfigFontStyle.initialize = function () 
	
	for i,v in ipairs(fonttable) do
		local fname, ffont = unpack(v);	
		info = UIDropDownMenu_CreateInfo()
		info.text = fname;
		info.func = config.ChangeFont;
		info.value = ffont;
		if(WhisperNotify_Config.Font == info.value) then
			info.checked = true;
		else
			info.checked = false;
		end
		UIDropDownMenu_AddButton(info)

	end --for	

	end;
	UIDropDownMenu_Initialize(ConfigFontStyle, ConfigFontStyle.initialize)
	UIDropDownMenu_SetSelectedValue(ConfigFontStyle,WhisperNotify_Config.Font );

-- *********************************************************************************************

	local fontsize = CreateFrame( "Slider", "WhisperNotify_FontSizeSlider", config, "OptionsSliderTemplate" );
	config.fontsize = fontsize;
	fontsize.id = "fontsize";
	fontsize:SetPoint( "BOTTOMLEFT", ConfigFontStyleLabel, 0, -50 );
	fontsize:SetWidth(300)
	fontsize:SetHeight(20)
	fontsize:SetOrientation('HORIZONTAL');
	fontsize:SetScript("OnValueChanged",config.ChangeFontSize);
	fontsize:SetMinMaxValues(1, 50) ;
	fontsize:SetValueStep(1);
	fontsize:SetValue(WhisperNotify_Config.FontSize);
	_G[ fontsize:GetName().."Low" ]:SetText( '1' );
	_G[ fontsize:GetName().."High" ]:SetText( '50' );
	_G[ fontsize:GetName().."Text" ]:SetText( '|c00dfb802Font Size');
 
 
	local currentfontsize = config:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" );
	config.currentfontsize = currentfontsize;
	currentfontsize:SetPoint( "CENTER",  fontsize, "BOTTOM", 0, -5);
	currentfontsize:SetText( WhisperNotify_Config.FontSize );
 
-- *********************************************************************************************	
	
	local  ConfigFontColor = CreateFrame( "Button", "WhisperNotify_FontColorButton", config );
	config.ConfigFontColor = ConfigFontColor;
	ConfigFontColor:SetHeight(40);
	ConfigFontColor:SetWidth(40);
	ConfigFontColor:SetScript("OnClick", config.ConfigFontColor_OnClick);
	ConfigFontColor:SetPoint( "BOTTOMLEFT" , fontsize, 0,-50);
	
	
	local colorSwatch = ConfigFontColor:CreateTexture("WhisperNotify_FontColorButtonColorSwatch", "OVERLAY");
	colorSwatch:SetWidth(19);
	colorSwatch:SetHeight(19);
	colorSwatch:SetTexture("Interface\\ChatFrame\\ChatFrameColorSwatch");
	colorSwatch:SetPoint("LEFT");
	colorSwatch:SetVertexColor(unpack(WhisperNotify_Config.FontColor));
	
	
	local texture = ConfigFontColor:CreateTexture(nil, "BACKGROUND");
	texture:SetWidth(16);
	texture:SetHeight(16);
	texture:SetTexture(1, 1, 1);
	texture:SetPoint("CENTER", colorSwatch);
	texture:Show();
	
	local ConfigFontColorLabel = config:CreateFontString( nil, "ARTWORK", "GameFontHighlight" );
	config.ConfigFontColorLabel = ConfigFontColorLabel;
	ConfigFontColorLabel:SetPoint( "RIGHT" , ConfigFontColor,"RIGHT",50,0);
	ConfigFontColorLabel:SetText( " |c00dfb802Font Color" );
	ConfigFontColor:Show();

-- *********************************************************************************************
		
	local ConfigFontColorPreview = config:CreateFontString( nil, "ARTWORK", "GameFontHighlight" );
	config.ConfigFontColorPreview = ConfigFontColorPreview;
	ConfigFontColorPreview:SetPoint( "BOTTOMLEFT" , ConfigFontColor,0,-22);
	ConfigFontColorPreview:SetText( "|c00dfb802Font size and color Preview" );
	
	local WhisperNotifyPreview = config:CreateFontString( nil, "ARTWORK", "NumberFontNormalHuge");
	config.WhisperNotifyPreview = WhisperNotifyPreview;
	WhisperNotifyPreview:SetText( "Whisper: Hi there!" );
--	WhisperNotifyPreview:SetTextHeight(WhisperNotify_Config.FontSize);
	WhisperNotifyPreview:SetPoint("BOTTOMLEFT", ConfigFontColorPreview, 0 , -60);
	WhisperNotifyPreview:SetFont(WhisperNotify_Config.Font, WhisperNotify_Config.FontSize); --new
	WhisperNotifyPreview:SetTextColor(unpack(WhisperNotify_Config.FontColor));

-- *********************************************************************************************	

InterfaceOptions_AddCategory(config);


end  --config:Init


-- *********************************************************************************************	
-- *********************************************************************************************	

function config2:ChangesizeH(self,value)
	if(value == true) then
		local newval =config2.sizeH:GetValue();
		config2.currentsizeH:SetText(newval);
		tempSizeH = newval;
		WhisperNotifyFrame:SetSize(tempSizeH, tempSizeV);
		WhisperNotifyFrame:SetUserPlaced(true);
--		print ('Changing Horizontal Size'); -- Debugging code
	end
end


function config2:ChangesizeV(self,value)
	if(value == true) then
		local newval =config2.sizeV:GetValue();
		config2.currentsizeV:SetText(newval);
		tempSizeV = newval;
		WhisperNotifyFrame:SetSize(tempSizeH, tempSizeV);
		WhisperNotifyFrame:SetUserPlaced(true);
--		print ('Changing Vertical Size'); -- Debugging code		
	end
end


function config2:ChangeoffsetH(self,value)
	if(value == true) then
		local newval =config2.offsetH:GetValue();
		config2.currentoffsetH:SetText(newval);
		tempOffsetH = newval;
		WhisperNotifyFrame:ClearAllPoints();
		WhisperNotifyFrame:SetPoint("CENTER", "UIParent", tempOffsetH, tempOffsetV );
		WhisperNotifyFrame:SetUserPlaced(true);
--		print ('Changing Horizontal Offset', tempOffsetH, tempOffsetV); -- Debugging code
	end
end


function config2:ChangeoffsetV(self,value)
	if(value == true) then
		local newval =config2.offsetV:GetValue();
		config2.currentoffsetV:SetText(newval);
		tempOffsetV = newval;
		WhisperNotifyFrame:ClearAllPoints();		
		WhisperNotifyFrame:SetPoint("CENTER", "UIParent", tempOffsetH, tempOffsetV );
		WhisperNotifyFrame:SetUserPlaced(true);
--		print ('Changing Vertical Offset', tempOffsetH, tempOffsetV); -- Debugging code		
	end
end


function config2:Init()

	config2.name = "Frame Size & Position";
	config2.parent = "Whisper Notify"
	config2:SetBackdrop({bgFile = "Interface/Tooltips/UI-Tooltip-Background", insets = { left = 2, right = 2, top = 2, bottom = 2 },})
	config2:SetBackdropColor(0.05, 0.05, 0.05, .7)

-- *********************************************************************************************

	local sizeH = CreateFrame( "Slider", "WhisperNotify_HorizontalSizeSlider", config2, "OptionsSliderTemplate" );
	config2.sizeH = sizeH;
	sizeH.id = "sizeH";
	sizeH:SetPoint( "TOPLEFT", 20, -25 );
	sizeH:SetWidth(300)
	sizeH:SetHeight(20)
	sizeH:SetOrientation('HORIZONTAL');
	sizeH:SetScript("OnValueChanged",config2.ChangesizeH);
	sizeH:SetMinMaxValues(100, 1920) ;
	sizeH:SetValueStep(10);
	sizeH:SetValue(tempSizeH);
	_G[ sizeH:GetName().."Low" ]:SetText( '100' );
	_G[ sizeH:GetName().."High" ]:SetText( '1920' );
	_G[ sizeH:GetName().."Text" ]:SetText( '|c00dfb802Frame Width');
	
	
	local currentsizeH = config2:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" );
	config2.currentsizeH = currentsizeH;
	currentsizeH:SetPoint( "CENTER",  sizeH, "BOTTOM", 0, -5);
	currentsizeH:SetText( tempSizeH );

-- *********************************************************************************************

	local sizeV = CreateFrame( "Slider", "WhisperNotify_VerticalSizeSlider", config2, "OptionsSliderTemplate" );
	config2.sizeV = sizeV;
	sizeV.id = "sizeV";
	sizeV:SetPoint( "BOTTOMLEFT", sizeH, 0, -50 );
	sizeV:SetWidth(300)
	sizeV:SetHeight(20)
	sizeV:SetOrientation('HORIZONTAL');
	sizeV:SetScript("OnValueChanged",config2.ChangesizeV);
	sizeV:SetMinMaxValues(100, 1080) ;
	sizeV:SetValueStep(10);
	sizeV:SetValue(tempSizeV);
	_G[ sizeV:GetName().."Low" ]:SetText( '100' );
	_G[ sizeV:GetName().."High" ]:SetText( '1080' );
	_G[ sizeV:GetName().."Text" ]:SetText( '|c00dfb802Frame Height');
	
	
	local currentsizeV = config2:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" );
	config2.currentsizeV = currentsizeV;
	currentsizeV:SetPoint( "CENTER",  sizeV, "BOTTOM", 0, -5);
	currentsizeV:SetText( tempSizeV );

-- *********************************************************************************************

	local offsetH = CreateFrame( "Slider", "WhisperNotify_HorizontalOffsetSlider", config2, "OptionsSliderTemplate" );
	config2.offsetH = offsetH;
	offsetH.id = "offsetH";
	offsetH:SetPoint( "BOTTOMLEFT", sizeV, 0, -75 );
	offsetH:SetWidth(300)
	offsetH:SetHeight(20)
	offsetH:SetOrientation('HORIZONTAL');
	offsetH:SetScript("OnValueChanged",config2.ChangeoffsetH);
	offsetH:SetMinMaxValues(-960, 960) ;
	offsetH:SetValueStep(10);
	offsetH:SetValue(tempOffsetH);
	_G[ offsetH:GetName().."Low" ]:SetText( '-960' );
	_G[ offsetH:GetName().."High" ]:SetText( '960' );
	_G[ offsetH:GetName().."Text" ]:SetText( '|c00dfb802 <-- Left -- Horizontal Offset  -- Right -->');
	
	
	local currentoffsetH = config2:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" );
	config2.currentoffsetH = currentoffsetH;
	currentoffsetH:SetPoint( "CENTER",  offsetH, "BOTTOM", 0, -5);
	currentoffsetH:SetText( tempOffsetH );

-- *********************************************************************************************

	local offsetV = CreateFrame( "Slider", "WhisperNotify_VerticalOffsetSlider", config2, "OptionsSliderTemplate" );
	config2.offsetV = offsetV;
	offsetV.id = "offsetV";
	offsetV:SetPoint( "BOTTOMLEFT", offsetH, 0, -50 );
	offsetV:SetWidth(300)
	offsetV:SetHeight(20)
	offsetV:SetOrientation('HORIZONTAL');
	offsetV:SetScript("OnValueChanged",config2.ChangeoffsetV);
	offsetV:SetMinMaxValues(-540, 540);
	offsetV:SetValueStep(10);
	offsetV:SetValue(tempOffsetV);
	_G[ offsetV:GetName().."Low" ]:SetText( '-540' );
	_G[ offsetV:GetName().."High" ]:SetText( '540' );
	_G[ offsetV:GetName().."Text" ]:SetText( '|c00dfb802<-- Down -- Vertical Offset -- Up -->');
	
	
	local currentoffsetV = config2:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" );
	config2.currentoffsetV = currentoffsetV;
	currentoffsetV:SetPoint( "CENTER",  offsetV, "BOTTOM", 0, -5);
	currentoffsetV:SetText( tempOffsetV );
	
-- *********************************************************************************************


InterfaceOptions_AddCategory(config2);

end --config2:Init

-- *********************************************************************************************	
-- *********************************************************************************************	


function config3:TestSound()
--	PlaySound(WhisperNotify_Config.SoundFile);
	PlaySoundFile("Interface\\AddOns\\WhisperNotify\\SoundFX\\"..WhisperNotify_Config.SoundFile)
end


function config3:ChangeSound()
	WhisperNotify_Config.SoundFile = self.value;								
	UIDropDownMenu_SetSelectedValue(config3.ConfigSound2Play,self.value,self.text);
end



function config3:ChangeSoundTime(self,value)
	if(value == true) then
		local newval =config3.TimeBetweenSounds:GetValue();
		config3.currentSoundTime:SetText(newval);
		WhisperNotify_Config.SoundTime = newval;
	end
end



function config3:Init()

	config3.name = "Sounds";
	config3.parent = "Whisper Notify"
	config3:SetBackdrop({bgFile = "Interface/Tooltips/UI-Tooltip-Background", insets = { left = 2, right = 2, top = 2, bottom = 2 },})
	config3:SetBackdropColor(0.05, 0.05, 0.05, .7)

-- *********************************************************************************************

	local TimeBetweenSounds = CreateFrame( "Slider", "WhisperNotify_SoundSlider", config3, "OptionsSliderTemplate" );
	config3.TimeBetweenSounds = TimeBetweenSounds;
	TimeBetweenSounds.id = "TimeBetweenSounds";
	TimeBetweenSounds:SetPoint( "TOPLEFT", 20, -25 );
	TimeBetweenSounds:SetWidth(300)
	TimeBetweenSounds:SetHeight(20)
	TimeBetweenSounds:SetOrientation('HORIZONTAL');
	TimeBetweenSounds:SetScript("OnValueChanged",config3.ChangeSoundTime);
	TimeBetweenSounds:SetMinMaxValues(0, 60) ;
	TimeBetweenSounds:SetValueStep(5);
	TimeBetweenSounds:SetValue(WhisperNotify_Config.SoundTime);
	_G[ TimeBetweenSounds:GetName().."Low" ]:SetText( '0' );
	_G[ TimeBetweenSounds:GetName().."High" ]:SetText( '60' );
	_G[ TimeBetweenSounds:GetName().."Text" ]:SetText( '|c00dfb802Minimum Time Between Sounds (in seconds)');
	
	
	local currentSoundTime = config3:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" );
	config3.currentSoundTime = currentSoundTime;
	currentSoundTime:SetPoint( "CENTER",  TimeBetweenSounds, "BOTTOM", 0, -5);
	currentSoundTime:SetText( WhisperNotify_Config.SoundTime );

-- *********************************************************************************************

	local ConfigSoundLabel = config3:CreateFontString( nil, "ARTWORK", "GameFontHighlight" );
	config3.ConfigSoundLabel = ConfigSoundLabel;
	ConfigSoundLabel:SetPoint( "BOTTOMLEFT" , TimeBetweenSounds,0,-40);
	ConfigSoundLabel:SetText( "|c00dfb802Sound to Play" );
	ConfigSoundLabel:Show();
	
	local ConfigSound2Play = CreateFrame("Frame", "WhisperNotify_SoundPick", config3, "UIDropDownMenuTemplate");
	config3.ConfigSound2Play = ConfigSound2Play;
	ConfigSound2Play:SetPoint("RIGHT", ConfigSoundLabel,30, 0);
	ConfigSound2Play.initialize = function () 
	
	for i,v in ipairs(soundtable) do
		local sname, svalue = unpack(v);	
		info = UIDropDownMenu_CreateInfo()
		info.text = sname;
		info.func = config3.ChangeSound;
		info.value = svalue;
		if(WhisperNotify_Config.SoundFile == info.value) then
			info.checked = true;
		else
			info.checked = false;
		end
		UIDropDownMenu_AddButton(info)

	end --for	

	end;
	UIDropDownMenu_Initialize(ConfigSound2Play, ConfigSound2Play.initialize)
	UIDropDownMenu_SetSelectedValue(ConfigSound2Play,WhisperNotify_Config.SoundFile);
	
-- *********************************************************************************************

	local ConfigTestSound = CreateFrame("BUTTON", nil, config3, "UIPanelButtonTemplate");
	ConfigTestSound:SetWidth(100);
	ConfigTestSound:SetHeight(25);
	ConfigTestSound:SetText("Play");
	ConfigTestSound:SetPoint("BOTTOMLEFT", ConfigSoundLabel, 0, -40);
	ConfigTestSound:SetScript("OnClick", config3.TestSound);

-- *********************************************************************************************
	
-- *********************************************************************************************


InterfaceOptions_AddCategory(config3);

end --config3:Init
